;; Generated package description from emacsql.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "emacsql" "4.3.6" "High-level SQL database front-end" '((emacs "26.1")) :commit "2fe6d4562b32a170a750d5e80514fbb6b6694803" :authors '(("Christopher Wellons" . "wellons@nullprogram.com")) :maintainer '("Jonas Bernoulli" . "emacs.emacsql@jonas.bernoulli.dev") :url "https://github.com/magit/emacsql")
